@@ -24,11 +24,20 @@ def _parse_text(text: str) -> str:
     replacements = {
         " ": "%20",
         "!": "%21",
+        '"': "%22",
         "#": "%23",
         "$": "%24",
         "%": "%25",
         "&": "%26",
+        "'": "%27",
+        "(": "%28",
+        ")": "%29",
         "*": "%2A",
+        "+": "%2B",
+        ",": "%2C",
+        "-": "%2D",
+        ".": "%2E",
+        "/": "%2F",
         "=": "%3D",
         "@": "%40",
         ":": "%3A",
